Class: Aws::BCMDataExports::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BCMDataExports::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bcmdataexports/client.rb,
sig/client.rbs
Overview
An API client for BCMDataExports. To construct a client, you need to configure a :region and :credentials.
client = Aws::BCMDataExports::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateExportResponseSuccess, _DeleteExportResponseSuccess, _GetExecutionResponseSuccess, _GetExportResponseSuccess, _GetTableResponseSuccess, _ListExecutionsResponseSuccess, _ListExportsResponseSuccess, _ListTablesResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateExportResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_export(params = {}) ⇒ Types::CreateExportResponse
Creates a data export and specifies the data query, the delivery preference, and any optional resource tags.
-
#delete_export(params = {}) ⇒ Types::DeleteExportResponse
Deletes an existing data export.
-
#get_execution(params = {}) ⇒ Types::GetExecutionResponse
Exports data based on the source data update.
-
#get_export(params = {}) ⇒ Types::GetExportResponse
Views the definition of an existing data export.
-
#get_table(params = {}) ⇒ Types::GetTableResponse
Returns the metadata for the specified table and table properties.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
Lists the historical executions for the export.
-
#list_exports(params = {}) ⇒ Types::ListExportsResponse
Lists all data export definitions.
-
#list_tables(params = {}) ⇒ Types::ListTablesResponse
Lists all available tables in data exports.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags associated with an existing data export.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags for an existing data export definition.
-
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with an existing data export definition.
-
#update_export(params = {}) ⇒ Types::UpdateExportResponse
Updates an existing data export by overwriting all export parameters.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1086 1087 1088 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1086 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1089 1090 1091 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1089 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1059 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BCMDataExports') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bcmdataexports' context[:gem_version] = '1.40.0' Seahorse::Client::Request.new(handlers, context) end |
#create_export(params = {}) ⇒ Types::CreateExportResponse
Creates a data export and specifies the data query, the delivery preference, and any optional resource tags.
A DataQuery consists of both a QueryStatement and
TableConfigurations.
The QueryStatement is an SQL statement. Data Exports only supports a
limited subset of the SQL syntax. For more information on the SQL
syntax that is supported, see Data query. To view the available
tables and columns, see the Data Exports table dictionary.
The TableConfigurations is a collection of specified
TableProperties for the table being queried in the QueryStatement.
TableProperties are additional configurations you can provide to
change the data and schema of a table. Each table can have different
TableProperties. However, tables are not required to have any
TableProperties. Each table property has a default value that it
assumes if not specified. For more information on table
configurations, see Data query. To view the table properties
available for each table, see the Data Exports table dictionary
or use the ListTables API to get a response of all tables and their
available properties.
87 |
# File 'sig/client.rbs', line 87
def create_export: (
|
#delete_export(params = {}) ⇒ Types::DeleteExportResponse
Deletes an existing data export.
103 |
# File 'sig/client.rbs', line 103
def delete_export: (
|
#get_execution(params = {}) ⇒ Types::GetExecutionResponse
Exports data based on the source data update.
115 |
# File 'sig/client.rbs', line 115
def get_execution: (
|
#get_export(params = {}) ⇒ Types::GetExportResponse
Views the definition of an existing data export.
127 |
# File 'sig/client.rbs', line 127
def get_export: (
|
#get_table(params = {}) ⇒ Types::GetTableResponse
Returns the metadata for the specified table and table properties. This includes the list of columns in the table schema, their data types, and column descriptions.
140 |
# File 'sig/client.rbs', line 140
def get_table: (
|
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
Lists the historical executions for the export.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
152 |
# File 'sig/client.rbs', line 152
def list_executions: (
|
#list_exports(params = {}) ⇒ Types::ListExportsResponse
Lists all data export definitions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
165 |
# File 'sig/client.rbs', line 165
def list_exports: (
|
#list_tables(params = {}) ⇒ Types::ListTablesResponse
Lists all available tables in data exports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
177 |
# File 'sig/client.rbs', line 177
def list_tables: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags associated with an existing data export.
189 |
# File 'sig/client.rbs', line 189
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags for an existing data export definition.
200 |
# File 'sig/client.rbs', line 200
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with an existing data export definition.
215 |
# File 'sig/client.rbs', line 215
def untag_resource: (
|
#update_export(params = {}) ⇒ Types::UpdateExportResponse
Updates an existing data export by overwriting all export parameters. All export parameters must be provided in the UpdateExport request.
226 |
# File 'sig/client.rbs', line 226
def update_export: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1079 1080 1081 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1079 def waiter_names [] end |