Class: Aws::BCMDataExports::Types::GetExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDataExports::Types::GetExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdataexports/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_id ⇒ String
The ID for this specific execution.
-
#export_arn ⇒ String
The Amazon Resource Name (ARN) of the Export object that generated this specific execution.
Instance Attribute Details
#execution_id ⇒ String
The ID for this specific execution.
303 304 305 306 307 308 |
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 303 class GetExecutionRequest < Struct.new( :export_arn, :execution_id) SENSITIVE = [] include Aws::Structure end |
#export_arn ⇒ String
The Amazon Resource Name (ARN) of the Export object that generated this specific execution.
303 304 305 306 307 308 |
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 303 class GetExecutionRequest < Struct.new( :export_arn, :execution_id) SENSITIVE = [] include Aws::Structure end |