Class: Aws::BCMDataExports::Types::GetTableResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdataexports/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The table description.



407
408
409
410
411
412
413
414
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 407

class GetTableResponse < Struct.new(
  :table_name,
  :description,
  :table_properties,
  :schema)
  SENSITIVE = []
  include Aws::Structure
end

#schemaArray<Types::Column>

The schema of the table.



407
408
409
410
411
412
413
414
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 407

class GetTableResponse < Struct.new(
  :table_name,
  :description,
  :table_properties,
  :schema)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table.



407
408
409
410
411
412
413
414
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 407

class GetTableResponse < Struct.new(
  :table_name,
  :description,
  :table_properties,
  :schema)
  SENSITIVE = []
  include Aws::Structure
end

#table_propertiesHash<String,String>

TableProperties are additional configurations you can provide to change the data and schema of a table. Each table can have different TableProperties. Tables are not required to have any TableProperties. Each table property has a default value that it assumes if not specified.



407
408
409
410
411
412
413
414
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 407

class GetTableResponse < Struct.new(
  :table_name,
  :description,
  :table_properties,
  :schema)
  SENSITIVE = []
  include Aws::Structure
end