Class: Aws::BCMDataExports::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdataexports/types.rb

Overview

You've reached the limit on the number of resources you can create, or exceeded the size of an individual resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 734

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :quota_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#quota_code ⇒ String

The quota code that was exceeded.

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 734

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :quota_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The identifier of the resource that exceeded quota.

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 734

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :quota_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

The type of the resource that exceeded quota.

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 734

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :quota_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#service_code ⇒ String

The service code that exceeded quota. It will always be “AWSBillingAndCostManagementDataExports”.

Returns:

  • (String)


734
735
736
737
738
739
740
741
742
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 734

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :quota_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end