Class: Aws::BCMDataExports::Types::ValidationExceptionField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bcmdataexports/types.rb

Overview

The input failed to meet the constraints specified by the Amazon Web Services service in a specified field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

A message with the reason for the validation exception error.

Returns:



930
931
932
933
934
935
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 930

class ValidationExceptionField < Struct.new(
  :name,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The field name where the invalid entry was detected.

Returns:



930
931
932
933
934
935
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 930

class ValidationExceptionField < Struct.new(
  :name,
  :message)
  SENSITIVE = []
  include Aws::Structure
end