Class: Aws::BCMDataExports::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BCMDataExports::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bcmdataexports/client.rb
Overview
An API client for BCMDataExports. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BCMDataExports::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_export(params = {}) ⇒ Types::CreateExportResponse
Creates a data export and specifies the data query, the delivery preference, and any optional resource tags.
-
#delete_export(params = {}) ⇒ Types::DeleteExportResponse
Deletes an existing data export.
-
#get_execution(params = {}) ⇒ Types::GetExecutionResponse
Exports data based on the source data update.
-
#get_export(params = {}) ⇒ Types::GetExportResponse
Views the definition of an existing data export.
-
#get_table(params = {}) ⇒ Types::GetTableResponse
Returns the metadata for the specified table and table properties.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
Lists the historical executions for the export.
-
#list_exports(params = {}) ⇒ Types::ListExportsResponse
Lists all data export definitions.
-
#list_tables(params = {}) ⇒ Types::ListTablesResponse
Lists all available tables in data exports.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags associated with an existing data export.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags for an existing data export definition.
-
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with an existing data export definition.
-
#update_export(params = {}) ⇒ Types::UpdateExportResponse
Updates an existing data export by overwriting all export parameters.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1088 1089 1090 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1088 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1091 1092 1093 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1091 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1061 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BCMDataExports') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bcmdataexports' context[:gem_version] = '1.35.0' Seahorse::Client::Request.new(handlers, context) end |
#create_export(params = {}) ⇒ Types::CreateExportResponse
Creates a data export and specifies the data query, the delivery preference, and any optional resource tags.
A ‘DataQuery` consists of both a `QueryStatement` and `TableConfigurations`.
The ‘QueryStatement` is an SQL statement. Data Exports only supports a limited subset of the SQL syntax. For more information on the SQL syntax that is supported, see [Data query]. To view the available tables and columns, see the [Data Exports table dictionary].
The ‘TableConfigurations` is a collection of specified `TableProperties` for the table being queried in the `QueryStatement`. TableProperties are additional configurations you can provide to change the data and schema of a table. Each table can have different TableProperties. However, tables are not required to have any TableProperties. Each table property has a default value that it assumes if not specified. For more information on table configurations, see [Data query]. To view the table properties available for each table, see the [Data Exports table dictionary] or use the `ListTables` API to get a response of all tables and their available properties.
[1]: docs.aws.amazon.com/cur/latest/userguide/de-data-query.html [2]: docs.aws.amazon.com/cur/latest/userguide/de-table-dictionary.html
576 577 578 579 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 576 def create_export(params = {}, = {}) req = build_request(:create_export, params) req.send_request() end |
#delete_export(params = {}) ⇒ Types::DeleteExportResponse
Deletes an existing data export.
604 605 606 607 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 604 def delete_export(params = {}, = {}) req = build_request(:delete_export, params) req.send_request() end |
#get_execution(params = {}) ⇒ Types::GetExecutionResponse
Exports data based on the source data update.
660 661 662 663 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 660 def get_execution(params = {}, = {}) req = build_request(:get_execution, params) req.send_request() end |
#get_export(params = {}) ⇒ Types::GetExportResponse
Views the definition of an existing data export.
709 710 711 712 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 709 def get_export(params = {}, = {}) req = build_request(:get_export, params) req.send_request() end |
#get_table(params = {}) ⇒ Types::GetTableResponse
Returns the metadata for the specified table and table properties. This includes the list of columns in the table schema, their data types, and column descriptions.
759 760 761 762 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 759 def get_table(params = {}, = {}) req = build_request(:get_table, params) req.send_request() end |
#list_executions(params = {}) ⇒ Types::ListExecutionsResponse
Lists the historical executions for the export.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
805 806 807 808 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 805 def list_executions(params = {}, = {}) req = build_request(:list_executions, params) req.send_request() end |
#list_exports(params = {}) ⇒ Types::ListExportsResponse
Lists all data export definitions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
848 849 850 851 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 848 def list_exports(params = {}, = {}) req = build_request(:list_exports, params) req.send_request() end |
#list_tables(params = {}) ⇒ Types::ListTablesResponse
Lists all available tables in data exports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
892 893 894 895 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 892 def list_tables(params = {}, = {}) req = build_request(:list_tables, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags associated with an existing data export.
932 933 934 935 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 932 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags for an existing data export definition.
964 965 966 967 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 964 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with an existing data export definition.
990 991 992 993 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 990 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_export(params = {}) ⇒ Types::UpdateExportResponse
Updates an existing data export by overwriting all export parameters. All export parameters must be provided in the UpdateExport request.
1052 1053 1054 1055 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1052 def update_export(params = {}, = {}) req = build_request(:update_export, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1081 1082 1083 |
# File 'lib/aws-sdk-bcmdataexports/client.rb', line 1081 def waiter_names [] end |