Class: Aws::BCMDataExports::Types::S3OutputConfigurations
- Inherits:
-
Struct
- Object
- Struct
- Aws::BCMDataExports::Types::S3OutputConfigurations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bcmdataexports/types.rb
Overview
The compression type, file format, and overwrite preference for the data export.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compression ⇒ String
The compression type for the data export.
-
#format ⇒ String
The file format for the data export.
-
#output_type ⇒ String
The output type for the data export.
-
#overwrite ⇒ String
The rule to follow when generating a version of the data export file.
Instance Attribute Details
#compression ⇒ String
The compression type for the data export.
700 701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 700 class S3OutputConfigurations < Struct.new( :output_type, :format, :compression, :overwrite) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The file format for the data export.
700 701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 700 class S3OutputConfigurations < Struct.new( :output_type, :format, :compression, :overwrite) SENSITIVE = [] include Aws::Structure end |
#output_type ⇒ String
The output type for the data export.
700 701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 700 class S3OutputConfigurations < Struct.new( :output_type, :format, :compression, :overwrite) SENSITIVE = [] include Aws::Structure end |
#overwrite ⇒ String
The rule to follow when generating a version of the data export file. You have the choice to overwrite the previous version or to be delivered in addition to the previous versions. Overwriting exports can save on Amazon S3 storage costs. Creating new export versions allows you to track the changes in cost and usage data over time.
700 701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-bcmdataexports/types.rb', line 700 class S3OutputConfigurations < Struct.new( :output_type, :format, :compression, :overwrite) SENSITIVE = [] include Aws::Structure end |